# PhosFox

*PhosFox* performs a peptide-level protein post-translational
modification (PTM) comparison between case and control settings.  It
detects which peptides have been *uniquely modified* (for example,
uniquely phosphorylated) in case and control samples, and writes the
differences into HTML-formatted report files.  Peptides and proteins
can be also written into separate files for further analyses.  Both
qualitative and quantitative data sets can be analyzed.  Peptide lists
originating from different search engines can be also compared.

If you are not familiar with the concepts and the process, please read
[Söderholm et al.](http://dx.doi.org/10.1186/1477-5956-12-36) first.

This README file describes the software requirements and installation
instructions.

# Requirements

To run *PhosFox*, you need the following software and inputs:

- [Perl](http://perl.org) version 5.6 or newer.  Most Unixes and
  unix-like operating systems (GNU/Linux, BSDs, OS X) have this
  already installed.  For Microsoft Windows we recommend
  [Strawberry Perl](http://strawberryperl.com), or the precompiled
  binary executable (see Installation below).

- Protein sequences in FASTA format.
  [UniProt](ftp://ftp.uniprot.org/pub/databases/uniprot/current_release/knowledgebase/proteomes/)
  and NCBI [RefSeq](ftp://ftp.ncbi.nlm.nih.gov/refseq/) FASTA formats
  are supported.

- Detected peptide lists in plain text format.  These usually come
  from proteomics analysis software such as *ProteinPilot* or
  *Mascot*.  See the manual for details for supported file types.  At
  least one case file and one control file is required.

# Installation

If you have a working Perl, download and extract the distribution
package
([tar.gz](https://bitbucket.org/phintsan/phosfox/downloads/phosfox.tar.gz),
[zip](https://bitbucket.org/phintsan/phosfox/downloads/phosfox.zip)).
All the required Perl modules are included in the package.  After
extraction, you should be able to run *PhosFox* simply by typing

    phosfox job-file.json

where `job-file.json` is the job file that specifies the input files
and parameters for the analysis.  See the user manual for details.
The distribution includes a job file template `job.json`, which you
can modify to suit your case.

For Windows platforms we have compiled a binary executable
[phosfox.exe](/phintsan/phosfox/downloads/phosfox.exe).  It should
work in both 32-bit and 64-bit Windows.  The executable is
stand-alone: no separate Perl environment nor any extra libraries are
needed.

In Unix, you may want to install *PhosFox* system-wide.  The following
steps should be enough:

1. Move `phosfox` into an appropriate binary directory, such as
`/usr/local/bin`.

2. Ensure that the system Perl has `Object::Tiny`, `JSON`, and
`Text::CSV` modules installed.  They are available in
[CPAN](http://www.cpan.org).

3. Move the `FIMM` and `PhosFox` modules (in `lib` directory) to some
directory in the Perl library path.  Typically
`/usr/local/lib/site_perl/` is one such directory.

## Post-translational modification databases

PhosFox can optionally detect novel acetylations and phosphorylations.
To use this feature, you have to separately download and install
database files.  See
[DATABASES.md](https://bitbucket.org/phintsan/phosfox/src/tip/DATABASES.md)
for instructions.

## Mercurial repository

If you want to track the latest developments, you can clone the source
code repository using [Mercurial](http://mercurial.selenic.com/).  See
<https://bitbucket.org/phintsan/phosfox/src>.  You will additionally
need to clone FIMM module repository from
<https://bitbucket.org/phintsan/fimm>.

# User manual

The user manual is available in
[HTML](https://bitbucket.org/phintsan/phosfox/downloads/phosfox.html)
and
[PDF](https://bitbucket.org/phintsan/phosfox/downloads/phosfox.pdf)
formats.  The same files are included in the distribution package.
After installation, typing `perldoc phosfox` should also display the
user manual.

# Copyright

Copyright 2013, 2014 Petteri Hintsanen <petterih@iki.fi>

This program is free software; you may redistribute it and/or modify
it under the same terms as Perl itself.
